# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Simplify

Package implementing a checker to help simplifying the code.

### Modules

SimplifyChecker | Module implementing the checker for simplifying Python code.
SimplifyNodeVisitor | Module implementing a node visitor checking for code that could be simplified.
translations | Module implementing message translations for the code style plugin messages (simplify part).